@@ -22,6 +22,7 @@ Functions
 * dumps
 * load
 * loads
+* tojson
 
 ## Usage Examples
 
@@ -63,6 +64,7 @@ Functions
 """
 
 from .bencode import bendecode, benencode
+from .exceptions import FilePathError
 
 
 def dump(obj, buffer):
@@ -85,10 +87,8 @@ def dump(obj, buffer):
     if not hasattr(buffer, "write"):
         with open(buffer, "wb") as _fd:
             _fd.write(encoded)
-
     else:
         buffer.write(encoded)
-        buffer.close()
 
 
 def dumps(obj):
@@ -106,7 +106,7 @@ def dumps(obj):
         Encoded data.
 
     """
-    return benencode(obj)
+    return bytes(benencode(obj))
 
 
 def load(buffer):
@@ -124,12 +124,17 @@ def load(buffer):
         (commonly `dict`), Decoded contents of file.
 
     """
+    if buffer in [None, ""]:
+        raise FilePathError(buffer)
+
     if hasattr(buffer, "read"):
         decoded, _ = bendecode(buffer.read())
-
     else:
-        with open(buffer, "rb") as _fd:
-            decoded, _ = bendecode(_fd.read())
+        try:
+            with open(buffer, "rb") as _fd:
+                decoded, _ = bendecode(_fd.read())
+        except FileNotFoundError as excp:
+            raise FilePathError(buffer) from excp
 
     return decoded
 
