@@ -62,7 +62,7 @@ class Bendecoder:
 
         Returns
         -------
-        any
+        `any`
             Decoded contents of file, Usually a dictionary.
 
         """
@@ -87,7 +87,7 @@ class Bendecoder:
 
         Returns
         -------
-        any
+        `any`
             Decoded data usually a dictionary.
 
         """
@@ -105,7 +105,7 @@ class Bendecoder:
 
         Returns
         -------
-        any :
+        `any` :
             the decoded data.
 
         """
@@ -124,13 +124,10 @@ class Bendecoder:
 
         Returns
         -------
-        any :
+        `any` :
             The decoded data.
 
         """
-        if bits is None:
-            bits = self.data
-
         if bits.startswith(b"i"):
             match, feed = self._decode_int(bits)
             return match, feed
@@ -258,7 +255,7 @@ class Benencoder:
 
         Args:
         ----
-        data : any
+        data : `any`
             (Optional) Target data for encoding. Defaults to None.
 
         """
@@ -272,7 +269,7 @@ class Benencoder:
 
         Args
         ----
-        data : any
+        data : `any`
             Raw data to be encoded, usually dict.txt
         path : path-like or `BytesIO`
             Where encoded data should be written to.py
@@ -297,7 +294,7 @@ class Benencoder:
 
         Args
         ----
-        data : any
+        data : `any`
             Raw data to be encoded usually a dictionary.
 
         Returns
